Package 'escape2024'

Title: Code accompanying the deliverable D4.1 of the ESCAPE project, 2024
Description: The package simulates SEIR epidemics for the mass action model and configuration network model that are described by ordinary differential equations. It contains functionality to calculates theoretical basic reproduction number and final size for the epidemic models. Scripts are included to produce the results presented in the 2024 deliverable D4.1 of the ESCAPE project.
Authors: Ka Yin Leung [aut, cre], Fuminari Miura [aut]
Maintainer: Ka Yin Leung <[email protected]>
License: EUPL v1.2 + file LICENSE
Version: 0.0.1
Built: 2026-05-17 06:53:52 UTC
Source: https://github.com/jgf5013/escape2024

Help Index


F(tau) function

Description

F(tau) function

Usage

.kernel_capital_curly_f(
  infection = c("SIR", "SEIR"),
  transmission_rate,
  infectiousness_rate = NULL,
  recovery_rate,
  tau
)

Arguments

infection

Derivative F'(tau)

Description

Derivative F'(tau)

Usage

.kernel_capital_curly_f_derivative(
  infection = c("SIR", "SEIR"),
  transmission_rate,
  infectiousness_rate = NULL,
  recovery_rate,
  tau
)

Arguments

infection

Title

Description

Title

Usage

.kernel_captial_curly_f_inf_limit(
  infection = c("SIR", "SEIR"),
  transmission_rate,
  infectiousness_rate = NULL,
  recovery_rate
)

Arguments

recovery_rate

Title

Description

Title

Usage

.ode_model_network_seir(t, current_state, params)

Arguments

params

Title

Description

Title

Usage

.ode_model_network_sir(t, current_state, params)

Arguments

params

Title

Description

Title

Usage

.ode_model_reference(t, current_state, params)

Arguments

params

Title

Description

Title

Usage

final_size(.data, precision = 1e-06)

Arguments

precision

G'(x) / G'(1) = G'(x) / , = mean degree, G(x) probability generating function

Description

G'(x) / G'(1) = G'(x) / , = mean degree, G(x) probability generating function

Usage

helper_g_function(x, ...)

Arguments

...

Derivative of helper_g_function G”(x) / G'(1) = G”(x) / , = mean degree, G(x) probability generating function

Description

Derivative of helper_g_function G”(x) / G'(1) = G”(x) / , = mean degree, G(x) probability generating function

Usage

helper_g_function_derivative(x, ...)

Arguments

...

Title

Description

Title

Usage

initial_x(seed_infected, degree_params)

Arguments

degree_params

Title

Description

Title

Usage

mean_degree(...)

Arguments

...

Title

Description

Title

Usage

mean_excess_degree(.degree)

Arguments

.degree

Title

Description

Title

Usage

model_network(
  degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"),
  infection = c("SIR", "SEIR"),
  transmission_rate = 1.25,
  infectiousness_rate = 0.25,
  recovery_rate = 0.2,
  time_end = 400,
  increment = 1,
  population_size = 2e+07,
  seed_infected = 0.001,
  ...
)

Arguments

...

Title

Description

Title

Usage

model_network_seir(
  degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"),
  transmission_rate = 0.25,
  infectiousness_rate = 0.1,
  recovery_rate = 0.25,
  population_size = 2e+07,
  seed_infected = 0.001,
  ...
)

Arguments

...

Title

Description

Title

Usage

model_network_sir(
  degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"),
  transmission_rate = 0.25,
  recovery_rate = 0.25,
  population_size = 2e+07,
  seed_infected = 0.001,
  ...
)

Arguments

...

Title

Description

Title

Usage

model_reference(
  transmission_rate = 0.25,
  infectiousness_rate = 0.25,
  recovery_rate = 0.2,
  population_size = 2e+07,
  seed_infected = 0.001
)

Arguments

seed_infected

Title

Description

Title

Usage

models_combined(time_end, increment, params_p, params_nb, params_reference)

Arguments

params_reference

Title

Description

Title

Usage

probability_generating_function(x, ...)

Arguments

...

Title

Description

Title

Usage

simulate_outbreak_seir_network(t, increment, current_state, params)

Arguments

params

Title

Description

Title

Usage

simulate_outbreak_seir_reference(t, increment, current_state, params)

Arguments

params

Title

Description

Title

Usage

simulate_outbreak_sir_network(t, increment, current_state, params)

Arguments

params

Title

Description

Title

Usage

theory_network_final_size(.params, .degree, .infection, .fraction = TRUE)

Arguments

.fraction

Title

Description

Title

Usage

theory_network_growth_rate(.infection, .params, .degree)

Arguments

.degree

Title

Description

Title

Usage

theory_network_reproduction_number(.infection, .params, .degree)

Arguments

.degree

Title

Description

Title

Usage

theory_reference_final_size(.params = NULL, r_0 = NULL, .fraction = TRUE)

Arguments

r_0

Title

Description

Title

Usage

theory_reference_growth_rate(.params)

Arguments

.params

Title

Description

Title

Usage

theory_reference_reproduction_number(.params)

Arguments

.params

Title

Description

Title

Usage

var_degree(...)

Arguments

...