| Title: | Code accompanying the deliverable D4.1 of the ESCAPE project, 2024 |
|---|---|
| Description: | The package simulates SEIR epidemics for the mass action model and configuration network model that are described by ordinary differential equations. It contains functionality to calculates theoretical basic reproduction number and final size for the epidemic models. Scripts are included to produce the results presented in the 2024 deliverable D4.1 of the ESCAPE project. |
| Authors: | Ka Yin Leung [aut, cre], Fuminari Miura [aut] |
| Maintainer: | Ka Yin Leung <[email protected]> |
| License: | EUPL v1.2 + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-17 06:53:52 UTC |
| Source: | https://github.com/jgf5013/escape2024 |
F(tau) function
.kernel_capital_curly_f( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate, tau ).kernel_capital_curly_f( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate, tau )
infection |
Derivative F'(tau)
.kernel_capital_curly_f_derivative( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate, tau ).kernel_capital_curly_f_derivative( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate, tau )
infection |
Title
.kernel_captial_curly_f_inf_limit( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate ).kernel_captial_curly_f_inf_limit( infection = c("SIR", "SEIR"), transmission_rate, infectiousness_rate = NULL, recovery_rate )
recovery_rate |
Title
.ode_model_network_seir(t, current_state, params).ode_model_network_seir(t, current_state, params)
params |
Title
.ode_model_network_sir(t, current_state, params).ode_model_network_sir(t, current_state, params)
params |
Title
.ode_model_reference(t, current_state, params).ode_model_reference(t, current_state, params)
params |
Title
final_size(.data, precision = 1e-06)final_size(.data, precision = 1e-06)
precision |
G'(x) / G'(1) = G'(x) /
helper_g_function(x, ...)helper_g_function(x, ...)
... |
Derivative of helper_g_function
G”(x) / G'(1) = G”(x) /
helper_g_function_derivative(x, ...)helper_g_function_derivative(x, ...)
... |
Title
initial_x(seed_infected, degree_params)initial_x(seed_infected, degree_params)
degree_params |
Title
mean_excess_degree(.degree)mean_excess_degree(.degree)
.degree |
Title
model_network( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), infection = c("SIR", "SEIR"), transmission_rate = 1.25, infectiousness_rate = 0.25, recovery_rate = 0.2, time_end = 400, increment = 1, population_size = 2e+07, seed_infected = 0.001, ... )model_network( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), infection = c("SIR", "SEIR"), transmission_rate = 1.25, infectiousness_rate = 0.25, recovery_rate = 0.2, time_end = 400, increment = 1, population_size = 2e+07, seed_infected = 0.001, ... )
... |
Title
model_network_seir( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), transmission_rate = 0.25, infectiousness_rate = 0.1, recovery_rate = 0.25, population_size = 2e+07, seed_infected = 0.001, ... )model_network_seir( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), transmission_rate = 0.25, infectiousness_rate = 0.1, recovery_rate = 0.25, population_size = 2e+07, seed_infected = 0.001, ... )
... |
Title
model_network_sir( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), transmission_rate = 0.25, recovery_rate = 0.25, population_size = 2e+07, seed_infected = 0.001, ... )model_network_sir( degree_distribution = c("poisson", "negative_binomial", "constant", "geometric"), transmission_rate = 0.25, recovery_rate = 0.25, population_size = 2e+07, seed_infected = 0.001, ... )
... |
Title
model_reference( transmission_rate = 0.25, infectiousness_rate = 0.25, recovery_rate = 0.2, population_size = 2e+07, seed_infected = 0.001 )model_reference( transmission_rate = 0.25, infectiousness_rate = 0.25, recovery_rate = 0.2, population_size = 2e+07, seed_infected = 0.001 )
seed_infected |
Title
models_combined(time_end, increment, params_p, params_nb, params_reference)models_combined(time_end, increment, params_p, params_nb, params_reference)
params_reference |
Title
probability_generating_function(x, ...)probability_generating_function(x, ...)
... |
Title
simulate_outbreak_seir_network(t, increment, current_state, params)simulate_outbreak_seir_network(t, increment, current_state, params)
params |
Title
simulate_outbreak_seir_reference(t, increment, current_state, params)simulate_outbreak_seir_reference(t, increment, current_state, params)
params |
Title
simulate_outbreak_sir_network(t, increment, current_state, params)simulate_outbreak_sir_network(t, increment, current_state, params)
params |
Title
theory_network_final_size(.params, .degree, .infection, .fraction = TRUE)theory_network_final_size(.params, .degree, .infection, .fraction = TRUE)
.fraction |
Title
theory_network_growth_rate(.infection, .params, .degree)theory_network_growth_rate(.infection, .params, .degree)
.degree |
Title
theory_network_reproduction_number(.infection, .params, .degree)theory_network_reproduction_number(.infection, .params, .degree)
.degree |
Title
theory_reference_final_size(.params = NULL, r_0 = NULL, .fraction = TRUE)theory_reference_final_size(.params = NULL, r_0 = NULL, .fraction = TRUE)
r_0 |
Title
theory_reference_growth_rate(.params)theory_reference_growth_rate(.params)
.params |
Title
theory_reference_reproduction_number(.params)theory_reference_reproduction_number(.params)
.params |